# web 常用服务

# 历史版本

```
0.0.1：权限管理\_api 多个项目使用
0.0.2：第一个试用版
0.0.3: 增加 api 权限过滤
0.0.3.1: 刷新 token.
0.0.3.2: 增加表 sys_dict 、 sys_dict_type 和 sys_config
0.0.3.x cacheManage
0.0.4 2024-07-26
0.0.5
字符格式化 right.po
0.0.6
cache
0.0.7 发布
```
